# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: plugin.proto
"""Generated protocol buffer code."""
from robomotion import struct_pb2 as struct__pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name='plugin.proto',
    package='proto',
    syntax='proto3',
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n\x0cplugin.proto\x12\x05proto\x1a\x0cstruct.proto\"2\n\x05\x45rror\x12\n\n\x02OK\x18\x02 \x01(\x08\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\"1\n\x0bInitRequest\x12\x14\n\x0c\x65vent_server\x18\x01 \x01(\r\x12\x0c\n\x04port\x18\x02 \x01(\r\"/\n\x0fOnCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\x0c\"/\n\x10OnCreateResponse\x12\x1b\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0c.proto.Error\"3\n\x10OnMessageRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x11\n\tinMessage\x18\x02 \x01(\x0c\"D\n\x11OnMessageResponse\x12\x12\n\noutMessage\x18\x01 \x01(\x0c\x12\x1b\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x0c.proto.Error\"\x1e\n\x0eOnCloseRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\".\n\x0fOnCloseResponse\x12\x1b\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0c.proto.Error\"\x07\n\x05\x45mpty\";\n\x0c\x44\x65\x62ugRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\x0c\"2\n\x14\x45mitFlowEventRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"?\n\x11\x45mitOutputRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x0e\n\x06output\x18\x02 \x01(\x0c\x12\x0c\n\x04port\x18\x03 \x01(\x05\"?\n\x10\x45mitErrorRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"6\n\x13GetVaultItemRequest\x12\x0f\n\x07vaultId\x18\x01 \x01(\t\x12\x0e\n\x06ItemId\x18\x02 \x01(\t\"=\n\x14GetVaultItemResponse\x12%\n\x04item\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"\'\n\x08Variable\x12\r\n\x05scope\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"7\n\x12GetVariableRequest\x12!\n\x08variable\x18\x01 \x01(\x0b\x32\x0f.proto.Variable\"=\n\x13GetVariableResponse\x12&\n\x05value\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"_\n\x12SetVariableRequest\x12!\n\x08variable\x18\x01 \x01(\x0b\x32\x0f.proto.Variable\x12&\n\x05value\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct2\xe7\x01\n\x04Node\x12(\n\x04Init\x12\x12.proto.InitRequest\x1a\x0c.proto.Empty\x12;\n\x08OnCreate\x12\x16.proto.OnCreateRequest\x1a\x17.proto.OnCreateResponse\x12>\n\tOnMessage\x12\x17.proto.OnMessageRequest\x1a\x18.proto.OnMessageResponse\x12\x38\n\x07OnClose\x12\x15.proto.OnCloseRequest\x1a\x16.proto.OnCloseResponse2\xcd\x03\n\rRuntimeHelper\x12#\n\x05\x43lose\x12\x0c.proto.Empty\x1a\x0c.proto.Empty\x12*\n\x05\x44\x65\x62ug\x12\x13.proto.DebugRequest\x1a\x0c.proto.Empty\x12:\n\rEmitFlowEvent\x12\x1b.proto.EmitFlowEventRequest\x1a\x0c.proto.Empty\x12\x34\n\nEmitOutput\x12\x18.proto.EmitOutputRequest\x1a\x0c.proto.Empty\x12\x32\n\tEmitError\x12\x17.proto.EmitErrorRequest\x1a\x0c.proto.Empty\x12G\n\x0cGetVaultItem\x12\x1a.proto.GetVaultItemRequest\x1a\x1b.proto.GetVaultItemResponse\x12\x44\n\x0bGetVariable\x12\x19.proto.GetVariableRequest\x1a\x1a.proto.GetVariableResponse\x12\x36\n\x0bSetVariable\x12\x19.proto.SetVariableRequest\x1a\x0c.proto.Emptyb\x06proto3',
    dependencies=[struct__pb2.DESCRIPTOR, ])


_ERROR = _descriptor.Descriptor(
    name='Error',
    full_name='proto.Error',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='OK', full_name='proto.Error.OK', index=0,
            number=2, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='code', full_name='proto.Error.code', index=1,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='message', full_name='proto.Error.message', index=2,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=37,
    serialized_end=87,
)


_INITREQUEST = _descriptor.Descriptor(
    name='InitRequest',
    full_name='proto.InitRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='event_server', full_name='proto.InitRequest.event_server', index=0,
            number=1, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='port', full_name='proto.InitRequest.port', index=1,
            number=2, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=89,
    serialized_end=138,
)


_ONCREATEREQUEST = _descriptor.Descriptor(
    name='OnCreateRequest',
    full_name='proto.OnCreateRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='name', full_name='proto.OnCreateRequest.name', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='config', full_name='proto.OnCreateRequest.config', index=1,
            number=2, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=b"",
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=140,
    serialized_end=187,
)


_ONCREATERESPONSE = _descriptor.Descriptor(
    name='OnCreateResponse',
    full_name='proto.OnCreateResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='error', full_name='proto.OnCreateResponse.error', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=189,
    serialized_end=236,
)


_ONMESSAGEREQUEST = _descriptor.Descriptor(
    name='OnMessageRequest',
    full_name='proto.OnMessageRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='guid', full_name='proto.OnMessageRequest.guid', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='inMessage', full_name='proto.OnMessageRequest.inMessage', index=1,
            number=2, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=b"",
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=238,
    serialized_end=289,
)


_ONMESSAGERESPONSE = _descriptor.Descriptor(
    name='OnMessageResponse',
    full_name='proto.OnMessageResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='outMessage', full_name='proto.OnMessageResponse.outMessage', index=0,
            number=1, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=b"",
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='error', full_name='proto.OnMessageResponse.error', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=291,
    serialized_end=359,
)


_ONCLOSEREQUEST = _descriptor.Descriptor(
    name='OnCloseRequest',
    full_name='proto.OnCloseRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='guid', full_name='proto.OnCloseRequest.guid', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=361,
    serialized_end=391,
)


_ONCLOSERESPONSE = _descriptor.Descriptor(
    name='OnCloseResponse',
    full_name='proto.OnCloseResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='error', full_name='proto.OnCloseResponse.error', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=393,
    serialized_end=439,
)


_EMPTY = _descriptor.Descriptor(
    name='Empty',
    full_name='proto.Empty',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=441,
    serialized_end=448,
)


_DEBUGREQUEST = _descriptor.Descriptor(
    name='DebugRequest',
    full_name='proto.DebugRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='guid', full_name='proto.DebugRequest.guid', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='name', full_name='proto.DebugRequest.name', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='message', full_name='proto.DebugRequest.message', index=2,
            number=3, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=b"",
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=450,
    serialized_end=509,
)


_EMITFLOWEVENTREQUEST = _descriptor.Descriptor(
    name='EmitFlowEventRequest',
    full_name='proto.EmitFlowEventRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='guid', full_name='proto.EmitFlowEventRequest.guid', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='name', full_name='proto.EmitFlowEventRequest.name', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=511,
    serialized_end=561,
)


_EMITOUTPUTREQUEST = _descriptor.Descriptor(
    name='EmitOutputRequest',
    full_name='proto.EmitOutputRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='guid', full_name='proto.EmitOutputRequest.guid', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='output', full_name='proto.EmitOutputRequest.output', index=1,
            number=2, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=b"",
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='port', full_name='proto.EmitOutputRequest.port', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=563,
    serialized_end=626,
)


_EMITERRORREQUEST = _descriptor.Descriptor(
    name='EmitErrorRequest',
    full_name='proto.EmitErrorRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='guid', full_name='proto.EmitErrorRequest.guid', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='name', full_name='proto.EmitErrorRequest.name', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='message', full_name='proto.EmitErrorRequest.message', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=628,
    serialized_end=691,
)


_GETVAULTITEMREQUEST = _descriptor.Descriptor(
    name='GetVaultItemRequest',
    full_name='proto.GetVaultItemRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='vaultId', full_name='proto.GetVaultItemRequest.vaultId', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='ItemId', full_name='proto.GetVaultItemRequest.ItemId', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=693,
    serialized_end=747,
)


_GETVAULTITEMRESPONSE = _descriptor.Descriptor(
    name='GetVaultItemResponse',
    full_name='proto.GetVaultItemResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='item', full_name='proto.GetVaultItemResponse.item', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=749,
    serialized_end=810,
)


_VARIABLE = _descriptor.Descriptor(
    name='Variable',
    full_name='proto.Variable',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='scope', full_name='proto.Variable.scope', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='name', full_name='proto.Variable.name', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=812,
    serialized_end=851,
)


_GETVARIABLEREQUEST = _descriptor.Descriptor(
    name='GetVariableRequest',
    full_name='proto.GetVariableRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='variable', full_name='proto.GetVariableRequest.variable', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=853,
    serialized_end=908,
)


_GETVARIABLERESPONSE = _descriptor.Descriptor(
    name='GetVariableResponse',
    full_name='proto.GetVariableResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='value', full_name='proto.GetVariableResponse.value', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=910,
    serialized_end=971,
)


_SETVARIABLEREQUEST = _descriptor.Descriptor(
    name='SetVariableRequest',
    full_name='proto.SetVariableRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='variable', full_name='proto.SetVariableRequest.variable', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
            name='value', full_name='proto.SetVariableRequest.value', index=1,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=973,
    serialized_end=1068,
)

_ONCREATERESPONSE.fields_by_name['error'].message_type = _ERROR
_ONMESSAGERESPONSE.fields_by_name['error'].message_type = _ERROR
_ONCLOSERESPONSE.fields_by_name['error'].message_type = _ERROR
_GETVAULTITEMRESPONSE.fields_by_name['item'].message_type = struct__pb2._STRUCT
_GETVARIABLEREQUEST.fields_by_name['variable'].message_type = _VARIABLE
_GETVARIABLERESPONSE.fields_by_name['value'].message_type = struct__pb2._STRUCT
_SETVARIABLEREQUEST.fields_by_name['variable'].message_type = _VARIABLE
_SETVARIABLEREQUEST.fields_by_name['value'].message_type = struct__pb2._STRUCT
DESCRIPTOR.message_types_by_name['Error'] = _ERROR
DESCRIPTOR.message_types_by_name['InitRequest'] = _INITREQUEST
DESCRIPTOR.message_types_by_name['OnCreateRequest'] = _ONCREATEREQUEST
DESCRIPTOR.message_types_by_name['OnCreateResponse'] = _ONCREATERESPONSE
DESCRIPTOR.message_types_by_name['OnMessageRequest'] = _ONMESSAGEREQUEST
DESCRIPTOR.message_types_by_name['OnMessageResponse'] = _ONMESSAGERESPONSE
DESCRIPTOR.message_types_by_name['OnCloseRequest'] = _ONCLOSEREQUEST
DESCRIPTOR.message_types_by_name['OnCloseResponse'] = _ONCLOSERESPONSE
DESCRIPTOR.message_types_by_name['Empty'] = _EMPTY
DESCRIPTOR.message_types_by_name['DebugRequest'] = _DEBUGREQUEST
DESCRIPTOR.message_types_by_name['EmitFlowEventRequest'] = _EMITFLOWEVENTREQUEST
DESCRIPTOR.message_types_by_name['EmitOutputRequest'] = _EMITOUTPUTREQUEST
DESCRIPTOR.message_types_by_name['EmitErrorRequest'] = _EMITERRORREQUEST
DESCRIPTOR.message_types_by_name['GetVaultItemRequest'] = _GETVAULTITEMREQUEST
DESCRIPTOR.message_types_by_name['GetVaultItemResponse'] = _GETVAULTITEMRESPONSE
DESCRIPTOR.message_types_by_name['Variable'] = _VARIABLE
DESCRIPTOR.message_types_by_name['GetVariableRequest'] = _GETVARIABLEREQUEST
DESCRIPTOR.message_types_by_name['GetVariableResponse'] = _GETVARIABLERESPONSE
DESCRIPTOR.message_types_by_name['SetVariableRequest'] = _SETVARIABLEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
    'DESCRIPTOR': _ERROR,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.Error)
})
_sym_db.RegisterMessage(Error)

InitRequest = _reflection.GeneratedProtocolMessageType('InitRequest', (_message.Message,), {
    'DESCRIPTOR': _INITREQUEST,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.InitRequest)
})
_sym_db.RegisterMessage(InitRequest)

OnCreateRequest = _reflection.GeneratedProtocolMessageType('OnCreateRequest', (_message.Message,), {
    'DESCRIPTOR': _ONCREATEREQUEST,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.OnCreateRequest)
})
_sym_db.RegisterMessage(OnCreateRequest)

OnCreateResponse = _reflection.GeneratedProtocolMessageType('OnCreateResponse', (_message.Message,), {
    'DESCRIPTOR': _ONCREATERESPONSE,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.OnCreateResponse)
})
_sym_db.RegisterMessage(OnCreateResponse)

OnMessageRequest = _reflection.GeneratedProtocolMessageType('OnMessageRequest', (_message.Message,), {
    'DESCRIPTOR': _ONMESSAGEREQUEST,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.OnMessageRequest)
})
_sym_db.RegisterMessage(OnMessageRequest)

OnMessageResponse = _reflection.GeneratedProtocolMessageType('OnMessageResponse', (_message.Message,), {
    'DESCRIPTOR': _ONMESSAGERESPONSE,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.OnMessageResponse)
})
_sym_db.RegisterMessage(OnMessageResponse)

OnCloseRequest = _reflection.GeneratedProtocolMessageType('OnCloseRequest', (_message.Message,), {
    'DESCRIPTOR': _ONCLOSEREQUEST,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.OnCloseRequest)
})
_sym_db.RegisterMessage(OnCloseRequest)

OnCloseResponse = _reflection.GeneratedProtocolMessageType('OnCloseResponse', (_message.Message,), {
    'DESCRIPTOR': _ONCLOSERESPONSE,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.OnCloseResponse)
})
_sym_db.RegisterMessage(OnCloseResponse)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
    'DESCRIPTOR': _EMPTY,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.Empty)
})
_sym_db.RegisterMessage(Empty)

DebugRequest = _reflection.GeneratedProtocolMessageType('DebugRequest', (_message.Message,), {
    'DESCRIPTOR': _DEBUGREQUEST,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.DebugRequest)
})
_sym_db.RegisterMessage(DebugRequest)

EmitFlowEventRequest = _reflection.GeneratedProtocolMessageType('EmitFlowEventRequest', (_message.Message,), {
    'DESCRIPTOR': _EMITFLOWEVENTREQUEST,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.EmitFlowEventRequest)
})
_sym_db.RegisterMessage(EmitFlowEventRequest)

EmitOutputRequest = _reflection.GeneratedProtocolMessageType('EmitOutputRequest', (_message.Message,), {
    'DESCRIPTOR': _EMITOUTPUTREQUEST,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.EmitOutputRequest)
})
_sym_db.RegisterMessage(EmitOutputRequest)

EmitErrorRequest = _reflection.GeneratedProtocolMessageType('EmitErrorRequest', (_message.Message,), {
    'DESCRIPTOR': _EMITERRORREQUEST,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.EmitErrorRequest)
})
_sym_db.RegisterMessage(EmitErrorRequest)

GetVaultItemRequest = _reflection.GeneratedProtocolMessageType('GetVaultItemRequest', (_message.Message,), {
    'DESCRIPTOR': _GETVAULTITEMREQUEST,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.GetVaultItemRequest)
})
_sym_db.RegisterMessage(GetVaultItemRequest)

GetVaultItemResponse = _reflection.GeneratedProtocolMessageType('GetVaultItemResponse', (_message.Message,), {
    'DESCRIPTOR': _GETVAULTITEMRESPONSE,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.GetVaultItemResponse)
})
_sym_db.RegisterMessage(GetVaultItemResponse)

Variable = _reflection.GeneratedProtocolMessageType('Variable', (_message.Message,), {
    'DESCRIPTOR': _VARIABLE,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.Variable)
})
_sym_db.RegisterMessage(Variable)

GetVariableRequest = _reflection.GeneratedProtocolMessageType('GetVariableRequest', (_message.Message,), {
    'DESCRIPTOR': _GETVARIABLEREQUEST,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.GetVariableRequest)
})
_sym_db.RegisterMessage(GetVariableRequest)

GetVariableResponse = _reflection.GeneratedProtocolMessageType('GetVariableResponse', (_message.Message,), {
    'DESCRIPTOR': _GETVARIABLERESPONSE,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.GetVariableResponse)
})
_sym_db.RegisterMessage(GetVariableResponse)

SetVariableRequest = _reflection.GeneratedProtocolMessageType('SetVariableRequest', (_message.Message,), {
    'DESCRIPTOR': _SETVARIABLEREQUEST,
    '__module__': 'plugin_pb2'
    # @@protoc_insertion_point(class_scope:proto.SetVariableRequest)
})
_sym_db.RegisterMessage(SetVariableRequest)


_NODE = _descriptor.ServiceDescriptor(
    name='Node',
    full_name='proto.Node',
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=1071,
    serialized_end=1302,
    methods=[
        _descriptor.MethodDescriptor(
            name='Init',
            full_name='proto.Node.Init',
            index=0,
            containing_service=None,
            input_type=_INITREQUEST,
            output_type=_EMPTY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='OnCreate',
            full_name='proto.Node.OnCreate',
            index=1,
            containing_service=None,
            input_type=_ONCREATEREQUEST,
            output_type=_ONCREATERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='OnMessage',
            full_name='proto.Node.OnMessage',
            index=2,
            containing_service=None,
            input_type=_ONMESSAGEREQUEST,
            output_type=_ONMESSAGERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='OnClose',
            full_name='proto.Node.OnClose',
            index=3,
            containing_service=None,
            input_type=_ONCLOSEREQUEST,
            output_type=_ONCLOSERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ])
_sym_db.RegisterServiceDescriptor(_NODE)

DESCRIPTOR.services_by_name['Node'] = _NODE


_RUNTIMEHELPER = _descriptor.ServiceDescriptor(
    name='RuntimeHelper',
    full_name='proto.RuntimeHelper',
    file=DESCRIPTOR,
    index=1,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=1305,
    serialized_end=1766,
    methods=[
        _descriptor.MethodDescriptor(
            name='Close',
            full_name='proto.RuntimeHelper.Close',
            index=0,
            containing_service=None,
            input_type=_EMPTY,
            output_type=_EMPTY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='Debug',
            full_name='proto.RuntimeHelper.Debug',
            index=1,
            containing_service=None,
            input_type=_DEBUGREQUEST,
            output_type=_EMPTY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='EmitFlowEvent',
            full_name='proto.RuntimeHelper.EmitFlowEvent',
            index=2,
            containing_service=None,
            input_type=_EMITFLOWEVENTREQUEST,
            output_type=_EMPTY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='EmitOutput',
            full_name='proto.RuntimeHelper.EmitOutput',
            index=3,
            containing_service=None,
            input_type=_EMITOUTPUTREQUEST,
            output_type=_EMPTY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='EmitError',
            full_name='proto.RuntimeHelper.EmitError',
            index=4,
            containing_service=None,
            input_type=_EMITERRORREQUEST,
            output_type=_EMPTY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='GetVaultItem',
            full_name='proto.RuntimeHelper.GetVaultItem',
            index=5,
            containing_service=None,
            input_type=_GETVAULTITEMREQUEST,
            output_type=_GETVAULTITEMRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='GetVariable',
            full_name='proto.RuntimeHelper.GetVariable',
            index=6,
            containing_service=None,
            input_type=_GETVARIABLEREQUEST,
            output_type=_GETVARIABLERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='SetVariable',
            full_name='proto.RuntimeHelper.SetVariable',
            index=7,
            containing_service=None,
            input_type=_SETVARIABLEREQUEST,
            output_type=_EMPTY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ])
_sym_db.RegisterServiceDescriptor(_RUNTIMEHELPER)

DESCRIPTOR.services_by_name['RuntimeHelper'] = _RUNTIMEHELPER

# @@protoc_insertion_point(module_scope)
