# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from robomotion import plugin_pb2 as plugin__pb2


class NodeStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Init = channel.unary_unary(
            '/proto.Node/Init',
            request_serializer=plugin__pb2.InitRequest.SerializeToString,
            response_deserializer=plugin__pb2.Empty.FromString,
        )
        self.OnCreate = channel.unary_unary(
            '/proto.Node/OnCreate',
            request_serializer=plugin__pb2.OnCreateRequest.SerializeToString,
            response_deserializer=plugin__pb2.OnCreateResponse.FromString,
        )
        self.OnMessage = channel.unary_unary(
            '/proto.Node/OnMessage',
            request_serializer=plugin__pb2.OnMessageRequest.SerializeToString,
            response_deserializer=plugin__pb2.OnMessageResponse.FromString,
        )
        self.OnClose = channel.unary_unary(
            '/proto.Node/OnClose',
            request_serializer=plugin__pb2.OnCloseRequest.SerializeToString,
            response_deserializer=plugin__pb2.OnCloseResponse.FromString,
        )


class NodeServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Init(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OnCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OnMessage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OnClose(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NodeServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'Init': grpc.unary_unary_rpc_method_handler(
            servicer.Init,
            request_deserializer=plugin__pb2.InitRequest.FromString,
            response_serializer=plugin__pb2.Empty.SerializeToString,
        ),
        'OnCreate': grpc.unary_unary_rpc_method_handler(
            servicer.OnCreate,
            request_deserializer=plugin__pb2.OnCreateRequest.FromString,
            response_serializer=plugin__pb2.OnCreateResponse.SerializeToString,
        ),
        'OnMessage': grpc.unary_unary_rpc_method_handler(
            servicer.OnMessage,
            request_deserializer=plugin__pb2.OnMessageRequest.FromString,
            response_serializer=plugin__pb2.OnMessageResponse.SerializeToString,
        ),
        'OnClose': grpc.unary_unary_rpc_method_handler(
            servicer.OnClose,
            request_deserializer=plugin__pb2.OnCloseRequest.FromString,
            response_serializer=plugin__pb2.OnCloseResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        'proto.Node', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

 # This class is part of an EXPERIMENTAL API.


class Node(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Init(request,
             target,
             options=(),
             channel_credentials=None,
             call_credentials=None,
             insecure=False,
             compression=None,
             wait_for_ready=None,
             timeout=None,
             metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.Node/Init',
                                             plugin__pb2.InitRequest.SerializeToString,
                                             plugin__pb2.Empty.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OnCreate(request,
                 target,
                 options=(),
                 channel_credentials=None,
                 call_credentials=None,
                 insecure=False,
                 compression=None,
                 wait_for_ready=None,
                 timeout=None,
                 metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.Node/OnCreate',
                                             plugin__pb2.OnCreateRequest.SerializeToString,
                                             plugin__pb2.OnCreateResponse.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OnMessage(request,
                  target,
                  options=(),
                  channel_credentials=None,
                  call_credentials=None,
                  insecure=False,
                  compression=None,
                  wait_for_ready=None,
                  timeout=None,
                  metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.Node/OnMessage',
                                             plugin__pb2.OnMessageRequest.SerializeToString,
                                             plugin__pb2.OnMessageResponse.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OnClose(request,
                target,
                options=(),
                channel_credentials=None,
                call_credentials=None,
                insecure=False,
                compression=None,
                wait_for_ready=None,
                timeout=None,
                metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.Node/OnClose',
                                             plugin__pb2.OnCloseRequest.SerializeToString,
                                             plugin__pb2.OnCloseResponse.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class RuntimeHelperStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Close = channel.unary_unary(
            '/proto.RuntimeHelper/Close',
            request_serializer=plugin__pb2.Empty.SerializeToString,
            response_deserializer=plugin__pb2.Empty.FromString,
        )
        self.Debug = channel.unary_unary(
            '/proto.RuntimeHelper/Debug',
            request_serializer=plugin__pb2.DebugRequest.SerializeToString,
            response_deserializer=plugin__pb2.Empty.FromString,
        )
        self.EmitFlowEvent = channel.unary_unary(
            '/proto.RuntimeHelper/EmitFlowEvent',
            request_serializer=plugin__pb2.EmitFlowEventRequest.SerializeToString,
            response_deserializer=plugin__pb2.Empty.FromString,
        )
        self.EmitOutput = channel.unary_unary(
            '/proto.RuntimeHelper/EmitOutput',
            request_serializer=plugin__pb2.EmitOutputRequest.SerializeToString,
            response_deserializer=plugin__pb2.Empty.FromString,
        )
        self.EmitError = channel.unary_unary(
            '/proto.RuntimeHelper/EmitError',
            request_serializer=plugin__pb2.EmitErrorRequest.SerializeToString,
            response_deserializer=plugin__pb2.Empty.FromString,
        )
        self.GetVaultItem = channel.unary_unary(
            '/proto.RuntimeHelper/GetVaultItem',
            request_serializer=plugin__pb2.GetVaultItemRequest.SerializeToString,
            response_deserializer=plugin__pb2.GetVaultItemResponse.FromString,
        )
        self.GetVariable = channel.unary_unary(
            '/proto.RuntimeHelper/GetVariable',
            request_serializer=plugin__pb2.GetVariableRequest.SerializeToString,
            response_deserializer=plugin__pb2.GetVariableResponse.FromString,
        )
        self.SetVariable = channel.unary_unary(
            '/proto.RuntimeHelper/SetVariable',
            request_serializer=plugin__pb2.SetVariableRequest.SerializeToString,
            response_deserializer=plugin__pb2.Empty.FromString,
        )


class RuntimeHelperServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Close(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Debug(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EmitFlowEvent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EmitOutput(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EmitError(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVaultItem(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVariable(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetVariable(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RuntimeHelperServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'Close': grpc.unary_unary_rpc_method_handler(
            servicer.Close,
            request_deserializer=plugin__pb2.Empty.FromString,
            response_serializer=plugin__pb2.Empty.SerializeToString,
        ),
        'Debug': grpc.unary_unary_rpc_method_handler(
            servicer.Debug,
            request_deserializer=plugin__pb2.DebugRequest.FromString,
            response_serializer=plugin__pb2.Empty.SerializeToString,
        ),
        'EmitFlowEvent': grpc.unary_unary_rpc_method_handler(
            servicer.EmitFlowEvent,
            request_deserializer=plugin__pb2.EmitFlowEventRequest.FromString,
            response_serializer=plugin__pb2.Empty.SerializeToString,
        ),
        'EmitOutput': grpc.unary_unary_rpc_method_handler(
            servicer.EmitOutput,
            request_deserializer=plugin__pb2.EmitOutputRequest.FromString,
            response_serializer=plugin__pb2.Empty.SerializeToString,
        ),
        'EmitError': grpc.unary_unary_rpc_method_handler(
            servicer.EmitError,
            request_deserializer=plugin__pb2.EmitErrorRequest.FromString,
            response_serializer=plugin__pb2.Empty.SerializeToString,
        ),
        'GetVaultItem': grpc.unary_unary_rpc_method_handler(
            servicer.GetVaultItem,
            request_deserializer=plugin__pb2.GetVaultItemRequest.FromString,
            response_serializer=plugin__pb2.GetVaultItemResponse.SerializeToString,
        ),
        'GetVariable': grpc.unary_unary_rpc_method_handler(
            servicer.GetVariable,
            request_deserializer=plugin__pb2.GetVariableRequest.FromString,
            response_serializer=plugin__pb2.GetVariableResponse.SerializeToString,
        ),
        'SetVariable': grpc.unary_unary_rpc_method_handler(
            servicer.SetVariable,
            request_deserializer=plugin__pb2.SetVariableRequest.FromString,
            response_serializer=plugin__pb2.Empty.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        'proto.RuntimeHelper', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

 # This class is part of an EXPERIMENTAL API.


class RuntimeHelper(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Close(request,
              target,
              options=(),
              channel_credentials=None,
              call_credentials=None,
              insecure=False,
              compression=None,
              wait_for_ready=None,
              timeout=None,
              metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.RuntimeHelper/Close',
                                             plugin__pb2.Empty.SerializeToString,
                                             plugin__pb2.Empty.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Debug(request,
              target,
              options=(),
              channel_credentials=None,
              call_credentials=None,
              insecure=False,
              compression=None,
              wait_for_ready=None,
              timeout=None,
              metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.RuntimeHelper/Debug',
                                             plugin__pb2.DebugRequest.SerializeToString,
                                             plugin__pb2.Empty.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EmitFlowEvent(request,
                      target,
                      options=(),
                      channel_credentials=None,
                      call_credentials=None,
                      insecure=False,
                      compression=None,
                      wait_for_ready=None,
                      timeout=None,
                      metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.RuntimeHelper/EmitFlowEvent',
                                             plugin__pb2.EmitFlowEventRequest.SerializeToString,
                                             plugin__pb2.Empty.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EmitOutput(request,
                   target,
                   options=(),
                   channel_credentials=None,
                   call_credentials=None,
                   insecure=False,
                   compression=None,
                   wait_for_ready=None,
                   timeout=None,
                   metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.RuntimeHelper/EmitOutput',
                                             plugin__pb2.EmitOutputRequest.SerializeToString,
                                             plugin__pb2.Empty.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EmitError(request,
                  target,
                  options=(),
                  channel_credentials=None,
                  call_credentials=None,
                  insecure=False,
                  compression=None,
                  wait_for_ready=None,
                  timeout=None,
                  metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.RuntimeHelper/EmitError',
                                             plugin__pb2.EmitErrorRequest.SerializeToString,
                                             plugin__pb2.Empty.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetVaultItem(request,
                     target,
                     options=(),
                     channel_credentials=None,
                     call_credentials=None,
                     insecure=False,
                     compression=None,
                     wait_for_ready=None,
                     timeout=None,
                     metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.RuntimeHelper/GetVaultItem',
                                             plugin__pb2.GetVaultItemRequest.SerializeToString,
                                             plugin__pb2.GetVaultItemResponse.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetVariable(request,
                    target,
                    options=(),
                    channel_credentials=None,
                    call_credentials=None,
                    insecure=False,
                    compression=None,
                    wait_for_ready=None,
                    timeout=None,
                    metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.RuntimeHelper/GetVariable',
                                             plugin__pb2.GetVariableRequest.SerializeToString,
                                             plugin__pb2.GetVariableResponse.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetVariable(request,
                    target,
                    options=(),
                    channel_credentials=None,
                    call_credentials=None,
                    insecure=False,
                    compression=None,
                    wait_for_ready=None,
                    timeout=None,
                    metadata=None):
        return grpc.experimental.unary_unary(request, target, '/proto.RuntimeHelper/SetVariable',
                                             plugin__pb2.SetVariableRequest.SerializeToString,
                                             plugin__pb2.Empty.FromString,
                                             options, channel_credentials,
                                             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
