# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: runner.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='runner.proto',
  package='proto',
  syntax='proto3',
  serialized_options=b'Z(robomotion/robomotion-runner/robot/proto',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0crunner.proto\x12\x05proto\"\x06\n\x04Null\"n\n\x11InitRunnerRequest\x12\x0e\n\x06\x61piUrl\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\x12\x14\n\x0crobot_server\x18\x03 \x01(\r\x12\x10\n\x08natsPort\x18\x04 \x01(\r\x12\x12\n\nrobot_name\x18\x05 \x01(\t\"T\n\nRunRequest\x12\x0e\n\x06repoid\x18\x01 \x01(\t\x12\x12\n\nrepository\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\"\'\n\x11RobotNameResponse\x12\x12\n\nrobot_name\x18\x01 \x01(\t\"\x05\n\x03Nil\"\x1f\n\rAttachRequest\x12\x0e\n\x06\x63onfig\x18\x01 \x01(\x0c\"\"\n\rDetachRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t2\xb5\x01\n\x06Runner\x12-\n\x04Init\x12\x18.proto.InitRunnerRequest\x1a\x0b.proto.Null\x12%\n\x03Run\x12\x11.proto.RunRequest\x1a\x0b.proto.Null\x12!\n\x05\x43lear\x12\x0b.proto.Null\x1a\x0b.proto.Null\x12\x32\n\tRobotName\x12\x0b.proto.Null\x1a\x18.proto.RobotNameResponse2\r\n\x0bRobotHelper2_\n\x05\x44\x65\x62ug\x12*\n\x06\x41ttach\x12\x14.proto.AttachRequest\x1a\n.proto.Nil\x12*\n\x06\x44\x65tach\x12\x14.proto.DetachRequest\x1a\n.proto.NilB*Z(robomotion/robomotion-runner/robot/protob\x06proto3'
)




_NULL = _descriptor.Descriptor(
  name='Null',
  full_name='proto.Null',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23,
  serialized_end=29,
)


_INITRUNNERREQUEST = _descriptor.Descriptor(
  name='InitRunnerRequest',
  full_name='proto.InitRunnerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='apiUrl', full_name='proto.InitRunnerRequest.apiUrl', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.InitRunnerRequest.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='robot_server', full_name='proto.InitRunnerRequest.robot_server', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='natsPort', full_name='proto.InitRunnerRequest.natsPort', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='robot_name', full_name='proto.InitRunnerRequest.robot_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31,
  serialized_end=141,
)


_RUNREQUEST = _descriptor.Descriptor(
  name='RunRequest',
  full_name='proto.RunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='repoid', full_name='proto.RunRequest.repoid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repository', full_name='proto.RunRequest.repository', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='proto.RunRequest.namespace', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='proto.RunRequest.version', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=143,
  serialized_end=227,
)


_ROBOTNAMERESPONSE = _descriptor.Descriptor(
  name='RobotNameResponse',
  full_name='proto.RobotNameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='robot_name', full_name='proto.RobotNameResponse.robot_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=229,
  serialized_end=268,
)


_NIL = _descriptor.Descriptor(
  name='Nil',
  full_name='proto.Nil',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=270,
  serialized_end=275,
)


_ATTACHREQUEST = _descriptor.Descriptor(
  name='AttachRequest',
  full_name='proto.AttachRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='proto.AttachRequest.config', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=277,
  serialized_end=308,
)


_DETACHREQUEST = _descriptor.Descriptor(
  name='DetachRequest',
  full_name='proto.DetachRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='proto.DetachRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=310,
  serialized_end=344,
)

DESCRIPTOR.message_types_by_name['Null'] = _NULL
DESCRIPTOR.message_types_by_name['InitRunnerRequest'] = _INITRUNNERREQUEST
DESCRIPTOR.message_types_by_name['RunRequest'] = _RUNREQUEST
DESCRIPTOR.message_types_by_name['RobotNameResponse'] = _ROBOTNAMERESPONSE
DESCRIPTOR.message_types_by_name['Nil'] = _NIL
DESCRIPTOR.message_types_by_name['AttachRequest'] = _ATTACHREQUEST
DESCRIPTOR.message_types_by_name['DetachRequest'] = _DETACHREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Null = _reflection.GeneratedProtocolMessageType('Null', (_message.Message,), {
  'DESCRIPTOR' : _NULL,
  '__module__' : 'runner_pb2'
  # @@protoc_insertion_point(class_scope:proto.Null)
  })
_sym_db.RegisterMessage(Null)

InitRunnerRequest = _reflection.GeneratedProtocolMessageType('InitRunnerRequest', (_message.Message,), {
  'DESCRIPTOR' : _INITRUNNERREQUEST,
  '__module__' : 'runner_pb2'
  # @@protoc_insertion_point(class_scope:proto.InitRunnerRequest)
  })
_sym_db.RegisterMessage(InitRunnerRequest)

RunRequest = _reflection.GeneratedProtocolMessageType('RunRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNREQUEST,
  '__module__' : 'runner_pb2'
  # @@protoc_insertion_point(class_scope:proto.RunRequest)
  })
_sym_db.RegisterMessage(RunRequest)

RobotNameResponse = _reflection.GeneratedProtocolMessageType('RobotNameResponse', (_message.Message,), {
  'DESCRIPTOR' : _ROBOTNAMERESPONSE,
  '__module__' : 'runner_pb2'
  # @@protoc_insertion_point(class_scope:proto.RobotNameResponse)
  })
_sym_db.RegisterMessage(RobotNameResponse)

Nil = _reflection.GeneratedProtocolMessageType('Nil', (_message.Message,), {
  'DESCRIPTOR' : _NIL,
  '__module__' : 'runner_pb2'
  # @@protoc_insertion_point(class_scope:proto.Nil)
  })
_sym_db.RegisterMessage(Nil)

AttachRequest = _reflection.GeneratedProtocolMessageType('AttachRequest', (_message.Message,), {
  'DESCRIPTOR' : _ATTACHREQUEST,
  '__module__' : 'runner_pb2'
  # @@protoc_insertion_point(class_scope:proto.AttachRequest)
  })
_sym_db.RegisterMessage(AttachRequest)

DetachRequest = _reflection.GeneratedProtocolMessageType('DetachRequest', (_message.Message,), {
  'DESCRIPTOR' : _DETACHREQUEST,
  '__module__' : 'runner_pb2'
  # @@protoc_insertion_point(class_scope:proto.DetachRequest)
  })
_sym_db.RegisterMessage(DetachRequest)


DESCRIPTOR._options = None

_RUNNER = _descriptor.ServiceDescriptor(
  name='Runner',
  full_name='proto.Runner',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=347,
  serialized_end=528,
  methods=[
  _descriptor.MethodDescriptor(
    name='Init',
    full_name='proto.Runner.Init',
    index=0,
    containing_service=None,
    input_type=_INITRUNNERREQUEST,
    output_type=_NULL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Run',
    full_name='proto.Runner.Run',
    index=1,
    containing_service=None,
    input_type=_RUNREQUEST,
    output_type=_NULL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Clear',
    full_name='proto.Runner.Clear',
    index=2,
    containing_service=None,
    input_type=_NULL,
    output_type=_NULL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RobotName',
    full_name='proto.Runner.RobotName',
    index=3,
    containing_service=None,
    input_type=_NULL,
    output_type=_ROBOTNAMERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RUNNER)

DESCRIPTOR.services_by_name['Runner'] = _RUNNER


_ROBOTHELPER = _descriptor.ServiceDescriptor(
  name='RobotHelper',
  full_name='proto.RobotHelper',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=530,
  serialized_end=543,
  methods=[
])
_sym_db.RegisterServiceDescriptor(_ROBOTHELPER)

DESCRIPTOR.services_by_name['RobotHelper'] = _ROBOTHELPER


_DEBUG = _descriptor.ServiceDescriptor(
  name='Debug',
  full_name='proto.Debug',
  file=DESCRIPTOR,
  index=2,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=545,
  serialized_end=640,
  methods=[
  _descriptor.MethodDescriptor(
    name='Attach',
    full_name='proto.Debug.Attach',
    index=0,
    containing_service=None,
    input_type=_ATTACHREQUEST,
    output_type=_NIL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Detach',
    full_name='proto.Debug.Detach',
    index=1,
    containing_service=None,
    input_type=_DETACHREQUEST,
    output_type=_NIL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DEBUG)

DESCRIPTOR.services_by_name['Debug'] = _DEBUG

# @@protoc_insertion_point(module_scope)
